@@ -778,9 +778,9 @@ class BaseExperiment:
         if not has_val_loss and not has_val_acc and not has_val_auc:
             raise AssertionError(f"No logged validation performances.")
 
-        val_loss = math.inf if not has_val_loss else val_loss
-        val_acc = -math.inf if not has_val_acc else val_acc
-        val_auc = -math.inf if not has_val_auc else val_auc
+        val_loss = math.nan if not has_val_loss else val_loss
+        val_acc = math.nan if not has_val_acc else val_acc
+        val_auc = math.nan if not has_val_auc else val_auc
 
         if isinstance(self.model, BaseEstimator):
             self.stack.append({"model" : self.model, "val_metrics": {'val/acc' : val_acc, 'val/loss' : val_loss, 'val/auc' : val_auc}})
